@@ -87,8 +87,8 @@ class HttpClient(object):
         if isinstance(method, basestring):
             request_json = rpcrequest.create_request_json(method, *args, **kwargs)
         else:
-            request_json = json.dumps(method)
             assert not args and not kwargs
+            request_json = json.dumps(method)
 
         # Call the HTTP-JSON-RPC server
         response_json = http_request(
@@ -97,19 +97,51 @@ class HttpClient(object):
             username = self.username,
             password = self.password
         )
+        if not response_json:
+            return
 
         # Convert JSON-RPC-response to python-object
         response = rpcresponse.parse_response_json(response_json)
+        if isinstance(response, rpcresponse.Response):
+            if response.error:
+                # Raise error
+                raise rpcerror.jsonrpcerrors[response.error.code](
+                    message = response.error.message,
+                    data = response.error.data
+                )
+            else:
+                # Return result
+                return response.result
+        elif isinstance(response, list):
+            # Bei Listen wird keine Fehlerauswerung gemacht
+            return response
 
-        if response.error:
-            # Raise error
-            raise rpcerror.jsonrpcerrors[response.error.code](
-                message = response.error.message,
-                data = response.error.data
-            )
+
+    def notify(self, method, *args, **kwargs):
+        """
+        Sends a notification or multiple notifications to the server.
+
+        A notification is a special request which does not have a response.
+        """
+
+        methods = []
+
+        # Create JSON-RPC-request
+        if isinstance(method, basestring):
+            request_dict = rpcrequest.create_request_dict(method, *args, **kwargs)
+            request_dict["id"] = None
+            methods.append(request_dict)
         else:
-            # Return result
-            return response.result
+            assert not args and not kwargs
+            for request_dict in method:
+                request_dict["id"] = None
+                methods.append(request_dict)
+
+        # Redirect to call-method
+        self.call(methods)
+
+        # Fertig
+        return
 
 
     def __call__(self, method, *args, **kwargs):
@@ -143,7 +175,6 @@ class HttpRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler, rpclib.JsonRpc):
     """
 
     protocol_version = "HTTP/1.1"
-    #server_version = "BaseHTTP/" + __version__
 
 
     def set_content_type_json(self):
@@ -214,7 +245,7 @@ class HttpRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler, rpclib.JsonRpc):
         request_json = json.dumps(request_dict)
 
         # Call
-        response_json = self.call(request_json)
+        response_json = self.call(request_json) or ""
 
         # Return result
         self.send_response(code = httplib.OK)
@@ -235,7 +266,7 @@ class HttpRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler, rpclib.JsonRpc):
         request_json = self.rfile.read(content_length)
 
         # Call
-        response_json = self.call(request_json)
+        response_json = self.call(request_json) or ""
 
         # Return result
         self.send_response(code = httplib.OK)
